Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(123)

Unified Diff: content/browser/zygote_host/zygote_communication_linux.cc

Issue 2950153002: Improve process launch handle sharing API. (Closed)
Patch Set: Merge Created 3 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/zygote_host/zygote_communication_linux.cc
diff --git a/content/browser/zygote_host/zygote_communication_linux.cc b/content/browser/zygote_host/zygote_communication_linux.cc
index 1c2192cafdc3f56a585bb53d01213623dc91e564..88f24452d81af0f780a97e544858e9d418c3086c 100644
--- a/content/browser/zygote_host/zygote_communication_linux.cc
+++ b/content/browser/zygote_host/zygote_communication_linux.cc
@@ -84,7 +84,7 @@ ssize_t ZygoteCommunication::ReadReply(void* buf, size_t buf_len) {
pid_t ZygoteCommunication::ForkRequest(
const std::vector<std::string>& argv,
- std::unique_ptr<FileDescriptorInfo> mapping,
+ std::unique_ptr<PosixFileDescriptorInfo> mapping,
const std::string& process_type) {
DCHECK(init_);
@@ -111,7 +111,7 @@ pid_t ZygoteCommunication::ForkRequest(
// First FD to send is peer_sock.
// TODO(morrita): Ideally, this should be part of the mapping so that
// FileDescriptorInfo can manages its lifetime.
fds.push_back(peer_sock.get());
// The rest come from mapping.
« no previous file with comments | « content/browser/zygote_host/zygote_communication_linux.h ('k') | content/browser/zygote_host/zygote_host_impl_linux.cc » ('j') | no next file with comments »
@@ -111,7 +111,7 @@ pid_t ZygoteCommunication::ForkRequest(
// First FD to send is peer_sock.
// TODO(morrita): Ideally, this should be part of the mapping so that
- // FileDescriptorInfo can manages its lifetime.
+ // PosixFileDescriptorInfo can manages its lifetime.
fds.push_back(peer_sock.get());
// The rest come from mapping.

Powered by Google App Engine
This is Rietveld 408576698